Специфікація формату XRD — XRCEA 0.2 documentation

# Специфікація формату XRD

Файли XRD містять опис дифрактограм.

## Огляд

Файл XRD складається з заголовка і двох колонок, розділених відступом. перша колонка може бути кутом \(2\theta\) або \(\theta\) в градусах, вектором дифракції \(4\pi \sin(\theta)/\lambda\). Друга колонка це експериментальна інтенсивність.

Рядки заголовка починають ся символом #, за яким іде ім’я змінної, яке закфнчується на двокрапці, після якої іде значення змінної.

    #name: Деяка значуща назва зразка
    #sample: powder
    #x_units: 2theta
    #I2: 0.46
    #lambda1: 1.540598
    #lambda2: 1.544426
    5   2
    5.1 3
    5.2 4

## Змінні:

\(\require{mediawiki-texvc}\)

- name назва зразка.

- contains елементний склад зразка.

- density атомна густина в \(\AA^{-3}\)

- x_units одиниці по осі абсцис: 2theta, theta, q

- lambda1 довжина хвилі в \({\AA}\) першої смуги

- lambda2 довжина хвилі в \(\AA\) другої смуги

- lambda3 довжина хвилі в \(\AA\) третьої смуги

- I2 інтенсивність першої смуги як частка першої

- I3 інтенсивність другої смуги як частка першої

- alpha1 кут відбиття монохроматора перед трубкою в градусах

- alpha2 кут відбиття монохроматора перед детектором в градусах